@@ -33,22 +33,20 @@
 
 """Self-test for Math.Numbers"""
 
+import sys
 import unittest
 
 from Crypto.SelfTest.st_common import list_test_cases
 
 from Crypto.Util.py3compat import *
 
-from Crypto.Math.Numbers import Integer as IntegerGeneric
-from Crypto.Math import _Numbers_int as NumbersInt
+from Crypto.Math._IntegerNative import IntegerNative
 
 
 class TestIntegerBase(unittest.TestCase):
 
     def setUp(self):
-        if not hasattr(self, "Integer"):
-            from Crypto.Math.Numbers import Integer as IntegerDefault
-            self.Integer = IntegerDefault
+        raise NotImplementedError("To be implemented")
 
     def Integers(self, *arg):
         return map(self.Integer, arg)
@@ -189,8 +187,8 @@ class TestIntegerBase(unittest.TestCase):
 
     def test_bool(self):
         v1, v2, v3, v4 = self.Integers(0, 10, -9, 2 ** 10)
-        self.failIf(v1)
-        self.failIf(bool(v1))
+        self.assertFalse(v1)
+        self.assertFalse(bool(v1))
         self.failUnless(v2)
         self.failUnless(bool(v2))
         self.failUnless(v3)
@@ -317,7 +315,7 @@ class TestIntegerBase(unittest.TestCase):
 
         # Test with all quadratic residues in several fields
         for p in (11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53):
-            for i in xrange(0, p):
+            for i in range(0, p):
                 square = i**2 % p
                 res = self.Integer(square).sqrt(p)
                 assert res in (i, p - i)
@@ -426,12 +424,18 @@ class TestIntegerBase(unittest.TestCase):
             v4 = self.Integer(0x90)
             v4 >>= -1
         self.assertRaises(ValueError, l)
-        def m():
+        def m1():
             v4 = self.Integer(0x90)
             v4 >>= 2 ** 1000
-        self.assertRaises(ValueError, m)
+            return v4
+        self.assertEqual(0, m1())
+        def m2():
+            v4 = self.Integer(-1)
+            v4 >>= 2 ** 1000
+            return v4
+        self.assertEqual(-1, m2())
 
-    def test_left_shift(self):
+    def _test_left_shift(self):
         v1, v2, v3 = self.Integers(0x10, 1, -0x10)
         self.assertEqual(v1 << 0, v1)
         self.failUnless(isinstance(v1 << v2, self.Integer))
@@ -441,7 +445,7 @@ class TestIntegerBase(unittest.TestCase):
         self.assertRaises(ValueError, lambda: v1 << -1)
         self.assertRaises(ValueError, lambda: v1 << (2 ** 1000))
 
-    def test_in_place_right_shift(self):
+    def test_in_place_left_shift(self):
         v1, v2, v3 = self.Integers(0x10, 1, -0x10)
         v1 <<= 0
         self.assertEqual(v1, 0x10)
@@ -519,7 +523,7 @@ class TestIntegerBase(unittest.TestCase):
         self.failUnless(self.Integer(39*39).is_perfect_square())
         self.failIf(self.Integer(39*39+1).is_perfect_square())
 
-        for x in xrange(100, 1000):
+        for x in range(100, 1000):
             self.failIf(self.Integer(x**2+1).is_perfect_square())
             self.failUnless(self.Integer(x**2).is_perfect_square())
 
@@ -664,41 +668,43 @@ class TestIntegerBase(unittest.TestCase):
         for n, kj in tv:
             for k, j in kj:
                 self.assertEqual(js(k, n), j)
+    
+    def test_hex(self):
+        v1, = self.Integers(0x10)
+        self.assertEqual(hex(v1), "0x10")
 
 
 class TestIntegerInt(TestIntegerBase):
 
     def setUp(self):
-        self.Numbers = NumbersInt
-        self.Integer = NumbersInt.Integer
-        TestIntegerBase.setUp(self)
+        self.Integer = IntegerNative
 
 
-class TestIntegerGeneric(unittest.TestCase):
+class testIntegerRandom(unittest.TestCase):
 
     def test_random_exact_bits(self):
 
-        for _ in xrange(1000):
-            a = IntegerGeneric.random(exact_bits=8)
+        for _ in range(1000):
+            a = IntegerNative.random(exact_bits=8)
             self.failIf(a < 128)
             self.failIf(a >= 256)
 
-        for bits_value in xrange(1024, 1024 + 8):
-            a = IntegerGeneric.random(exact_bits=bits_value)
+        for bits_value in range(1024, 1024 + 8):
+            a = IntegerNative.random(exact_bits=bits_value)
             self.failIf(a < 2**(bits_value - 1))
             self.failIf(a >= 2**bits_value)
 
     def test_random_max_bits(self):
 
         flag = False
-        for _ in xrange(1000):
-            a = IntegerGeneric.random(max_bits=8)
+        for _ in range(1000):
+            a = IntegerNative.random(max_bits=8)
             flag = flag or a < 128
             self.failIf(a>=256)
         self.failUnless(flag)
 
-        for bits_value in xrange(1024, 1024 + 8):
-            a = IntegerGeneric.random(max_bits=bits_value)
+        for bits_value in range(1024, 1024 + 8):
+            a = IntegerNative.random(max_bits=bits_value)
             self.failIf(a >= 2**bits_value)
 
     def test_random_bits_custom_rng(self):
@@ -712,18 +718,18 @@ class TestIntegerGeneric(unittest.TestCase):
                 return bchr(0) * size
 
         custom_rng = CustomRNG()
-        a = IntegerGeneric.random(exact_bits=32, randfunc=custom_rng)
+        a = IntegerNative.random(exact_bits=32, randfunc=custom_rng)
         self.assertEqual(custom_rng.counter, 4)
 
     def test_random_range(self):
 
-        func = IntegerGeneric.random_range
+        func = IntegerNative.random_range
 
-        for x in xrange(200):
+        for x in range(200):
             a = func(min_inclusive=1, max_inclusive=15)
             self.failUnless(1 <= a <= 15)
 
-        for x in xrange(200):
+        for x in range(200):
             a = func(min_inclusive=1, max_exclusive=15)
             self.failUnless(1 <= a < 15)
 
@@ -734,36 +740,33 @@ class TestIntegerGeneric(unittest.TestCase):
 def get_tests(config={}):
     tests = []
     tests += list_test_cases(TestIntegerInt)
-
+    
     try:
-        from Crypto.Math import _Numbers_gmp as NumbersGMP
+        from Crypto.Math._IntegerGMP import IntegerGMP
 
         class TestIntegerGMP(TestIntegerBase):
             def setUp(self):
-                self.Numbers = NumbersGMP
-                self.Integer = NumbersGMP.Integer
-                TestIntegerBase.setUp(self)
+                self.Integer = IntegerGMP
 
         tests += list_test_cases(TestIntegerGMP)
     except (ImportError, OSError) as e:
-        import sys
-        sys.stdout.write("Skipping GMP tests (%s)\n" % str(e) )
+        if sys.platform == "win32":
+            sys.stdout.write("Skipping GMP tests on Windows\n")
+        else:
+            sys.stdout.write("Skipping GMP tests (%s)\n" % str(e) )
 
     try:
-        from Crypto.Math import _Numbers_custom as NumbersCustomModexp
+        from Crypto.Math._IntegerCustom import IntegerCustom
 
         class TestIntegerCustomModexp(TestIntegerBase):
             def setUp(self):
-                self.Numbers = NumbersCustomModexp
-                self.Integer = NumbersCustomModexp.Integer
-                TestIntegerBase.setUp(self)
+                self.Integer = IntegerCustom
 
         tests += list_test_cases(TestIntegerCustomModexp)
     except (ImportError, OSError) as e:
-        import sys
         sys.stdout.write("Skipping custom modexp tests (%s)\n" % str(e) )
 
-    tests += list_test_cases(TestIntegerGeneric)
+    tests += list_test_cases(testIntegerRandom)
     return tests
 
 if __name__ == '__main__':
