@@ -189,7 +189,7 @@ class TestImport_P256(unittest.TestCase):
         # We just check if the import succeeds
 
     def test_import_private_pem_encrypted(self):
-        for algo in "des3", "aes128", "aes192", "aes256_gcm":
+        for algo in "des3", "aes128", "aes192", "aes256", "aes256_gcm":
             key_file = load_file("ecc_p256_private_enc_%s.pem" % algo)
 
             key = ECC.import_key(key_file, "secret")
@@ -204,15 +204,31 @@ class TestImport_P256(unittest.TestCase):
         key = ECC.import_key(key_file)
         self.assertEqual(self.ref_public, key)
 
-    def test_import_openssh(self):
+    def test_import_openssh_public(self):
         key_file = load_file("ecc_p256_public_openssh.txt")
 
-        key = ECC._import_openssh(key_file)
+        key = ECC._import_openssh_public(key_file)
         self.assertEqual(self.ref_public, key)
 
         key = ECC.import_key(key_file)
         self.assertEqual(self.ref_public, key)
 
+    def test_import_openssh_private_clear(self):
+        key_file = load_file("ecc_p256_private_openssh.pem")
+        key_file_old = load_file("ecc_p256_private_openssh_old.pem")
+
+        key = ECC.import_key(key_file)
+        key_old = ECC.import_key(key_file_old)
+        self.assertEqual(key, key_old)
+
+    def test_import_openssh_private_password(self):
+        key_file = load_file("ecc_p256_private_openssh_pwd.pem")
+        key_file_old = load_file("ecc_p256_private_openssh_pwd_old.pem")
+
+        key = ECC.import_key(key_file, b"password")
+        key_old = ECC.import_key(key_file_old)
+        self.assertEqual(key, key_old)
+
 
 class TestImport_P384(unittest.TestCase):
 
@@ -294,7 +310,7 @@ class TestImport_P384(unittest.TestCase):
         self.assertEqual(self.ref_private, key)
 
     def test_import_private_pem_encrypted(self):
-        for algo in "des3", "aes128", "aes192", "aes256_gcm":
+        for algo in "des3", "aes128", "aes192", "aes256", "aes256_gcm":
             key_file = load_file("ecc_p384_private_enc_%s.pem" % algo)
 
             key = ECC.import_key(key_file, "secret")
@@ -309,15 +325,31 @@ class TestImport_P384(unittest.TestCase):
         key = ECC.import_key(key_file)
         self.assertEqual(self.ref_public, key)
 
-    def test_import_openssh(self):
+    def test_import_openssh_public(self):
         key_file = load_file("ecc_p384_public_openssh.txt")
 
-        key = ECC._import_openssh(key_file)
+        key = ECC._import_openssh_public(key_file)
         self.assertEqual(self.ref_public, key)
 
         key = ECC.import_key(key_file)
         self.assertEqual(self.ref_public, key)
 
+    def test_import_openssh_private_clear(self):
+        key_file = load_file("ecc_p384_private_openssh.pem")
+        key_file_old = load_file("ecc_p384_private_openssh_old.pem")
+
+        key = ECC.import_key(key_file)
+        key_old = ECC.import_key(key_file_old)
+        self.assertEqual(key, key_old)
+
+    def test_import_openssh_private_password(self):
+        key_file = load_file("ecc_p384_private_openssh_pwd.pem")
+        key_file_old = load_file("ecc_p384_private_openssh_pwd_old.pem")
+
+        key = ECC.import_key(key_file, b"password")
+        key_old = ECC.import_key(key_file_old)
+        self.assertEqual(key, key_old)
+
 
 class TestImport_P521(unittest.TestCase):
 
@@ -399,7 +431,7 @@ class TestImport_P521(unittest.TestCase):
         self.assertEqual(self.ref_private, key)
 
     def test_import_private_pem_encrypted(self):
-        for algo in "des3", "aes128", "aes192", "aes256_gcm":
+        for algo in "des3", "aes128", "aes192", "aes256", "aes256_gcm":
             key_file = load_file("ecc_p521_private_enc_%s.pem" % algo)
 
             key = ECC.import_key(key_file, "secret")
@@ -414,15 +446,31 @@ class TestImport_P521(unittest.TestCase):
         key = ECC.import_key(key_file)
         self.assertEqual(self.ref_public, key)
 
-    def test_import_openssh(self):
+    def test_import_openssh_public(self):
         key_file = load_file("ecc_p521_public_openssh.txt")
 
-        key = ECC._import_openssh(key_file)
+        key = ECC._import_openssh_public(key_file)
         self.assertEqual(self.ref_public, key)
 
         key = ECC.import_key(key_file)
         self.assertEqual(self.ref_public, key)
 
+    def test_import_openssh_private_clear(self):
+        key_file = load_file("ecc_p521_private_openssh.pem")
+        key_file_old = load_file("ecc_p521_private_openssh_old.pem")
+
+        key = ECC.import_key(key_file)
+        key_old = ECC.import_key(key_file_old)
+        self.assertEqual(key, key_old)
+
+    def test_import_openssh_private_password(self):
+        key_file = load_file("ecc_p521_private_openssh_pwd.pem")
+        key_file_old = load_file("ecc_p521_private_openssh_pwd_old.pem")
+
+        key = ECC.import_key(key_file, b"password")
+        key_old = ECC.import_key(key_file_old)
+        self.assertEqual(key, key_old)
+
 
 class TestExport_P256(unittest.TestCase):
 
